from setuptools import setup

setup(
    name='NlpToolkit-Util',
    version='1.0.4',
    packages=['Util'],
    url='https://github.com/olcaytaner/Util-Py',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='Simple Utils'
)
